@@ -5,11 +5,11 @@ use App::SimulateReads::Base 'class';
 
 extends 'App::SimulateReads::CLI::App';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 sub command_map {
-	digest    => 'App::SimulateReads::Command::Digest',
-	qualitydb =>  'App::SimulateReads::Command::QualityDB'
+	simulate  => 'App::SimulateReads::Command::Simulate',
+	qualitydb => 'App::SimulateReads::Command::QualityDB'
 }
 
 __END__
@@ -24,7 +24,7 @@ App::SimulateReads - App builder that simulates single-end and paired-end reads.
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -41,7 +41,7 @@ version 0.10
   man                      show application or command-specific documentation
 
  Main commands:
-  digest                   digest a fasta file into single|paired-end reads 
+  simulate                 manage genome/transcriptome sequencing simulation
   qualitydb                manage quality profile database
 
 =head1 DESCRIPTION
@@ -55,7 +55,7 @@ Thiago L. A. Miller <tmiller@mochsl.org.br>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Teaching and Research Institute from Sírio-Libanês Hospital.
+This software is Copyright (c) 2018 by Teaching and Research Institute from Sírio-Libanês Hospital.
 
 This is free software, licensed under:
 
