@@ -50,10 +50,10 @@ sub sprint_fastq : Tests(6) {
 
 	my $id = "SR0001";
 	my $seq_name = "Chr1";
-	my ($read1_ref, $read2_ref) = $fastq->sprint_fastq($id, $seq_name, \$seq, length $seq, 1);
+	my ($read1_ref, $read2_ref) = $fastq->sprint_fastq($id, 1, $seq_name, \$seq, length $seq, 1);
 	my $read_size = $fastq->read_size;
-	my $header = qr/$id simulation_read length=$read_size position=${seq_name}:\d+-\d+/;
-	my $rg = qr/\@${header}\n.+\n\+\n.+/;
+	my $header = qr/simulation_read length=$read_size position=${seq_name}:\d+-\d+/;
+	my $rg = qr/\@.+${header}\n.+\n\+\n.+/;
 
 	for ($read1_ref, $read2_ref) {
 		ok $$_ =~ $rg,
@@ -81,7 +81,7 @@ sub sprint_fastq : Tests(6) {
 		"The seq_name:end-start inside read 2 fastq header should be the correct relative position";
 	
 	# Testing retarded strand paired-end fastq
-	my ($read2_1_ref, $read2_2_ref) = $fastq->sprint_fastq($id, $seq_name, \$seq, length $seq, 0);
+	my ($read2_1_ref, $read2_2_ref) = $fastq->sprint_fastq($id, 1, $seq_name, \$seq, length $seq, 0);
 
 	my @lines3 = split /\n/ => $$read2_1_ref;
 	$fastq->_read->reverse_complement(\$lines3[1]);
